@@ -5,30 +5,12 @@ from typing import TYPE_CHECKING
 if TYPE_CHECKING:
     from collections.abc import Mapping
     from collections.abc import MutableMapping
-    from collections.abc import Iterator
-    from typing import Any, Iterable
-    from typing_extensions import TypedDict
-    from typing_extensions import Protocol
-    from typing_extensions import TypeAlias
+
+    from _typeshed.wsgi import ErrorStream
+    from _typeshed.wsgi import InputStream
     from typing_extensions import NotRequired
-    from typing import Callable
-
-    from types import TracebackType
-
-    _ExcInfo: TypeAlias = "tuple[type[BaseException], BaseException, TracebackType]"
-    _OptExcInfo: TypeAlias = "_ExcInfo | tuple[None, None, None]"
-
-    class StartResponse(Protocol):
-        def __call__(
-            self,
-            status: str,
-            headers: list[tuple[str, str]],
-            exc_info: _OptExcInfo | None = ...,
-            /,
-        ) -> Callable[[bytes], object]: ...
-
-    WSGIEnvironment: TypeAlias = "dict[str, Any]"
-    WSGIApplication: TypeAlias = Callable[[WSGIEnvironment, StartResponse], Iterable[bytes]]
+    from typing_extensions import Protocol
+    from typing_extensions import TypedDict
 
     Environ = TypedDict(
         "Environ",
@@ -38,10 +20,10 @@ if TYPE_CHECKING:
             "PATH_INFO": str,
             "QUERY_STRING": str,
             "SERVER_PROTOCOL": str,
-            "wsig.version": tuple[int, int],  # type: ignore[misc]
+            "wsig.version": tuple[int, int],
             "wsgi.url_scheme": str,
-            "wsgi.input": "InputStream",
-            "wsgi.errors": "ErrorStream",
+            "wsgi.input": InputStream,
+            "wsgi.errors": ErrorStream,
             "wsgi.multithread": bool,
             "wsgi.multiprocess": bool,
             "wsgi.run_once": bool,
@@ -51,30 +33,6 @@ if TYPE_CHECKING:
         },
     )
 
-    class InputStream(Protocol):
-        def read(self, size: int = ..., /) -> bytes: ...
-        def readline(self, size: int = ..., /) -> bytes: ...
-        def readlines(self, hint: int = ..., /) -> list[bytes]: ...
-        def __iter__(self) -> Iterator[bytes]: ...
-
-    class ErrorStream(Protocol):
-        def flush(self) -> object: ...
-        def write(self, s: str, /) -> object: ...
-        def writelines(self, seq: list[str], /) -> object: ...
-
-    class _Readable(Protocol):
-        def read(self, size: int = ..., /) -> bytes: ...
-
-        # Optional: def close(self) -> object: ...
-
-    class FileWrapper(Protocol):
-        def __call__(
-            self,
-            file: _Readable,
-            block_size: int = ...,
-            /,
-        ) -> Iterable[bytes]: ...
-
     ################################################################
     class LambdaContextLike(Protocol):
         @property
